@@ -16,7 +16,5 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
-sync_schema_props_perms('has_data')
-sync_schema_props_perms('results_file')
-
-drop_attribute('Scan', 'timepoint')
+add_cube('file')
+add_relation_definition('Scan', 'results_file', 'File')
